@@ -20,3 +20,9 @@ context("hot_renderer / dq_hot_html_renderer")
 test_that("dq_hot_html_renderer works", {
   expect_silent(dq_hot_html_renderer())
 })
+
+context("hot_renderer / dq_hot_selectize_renderer")
+
+test_that("dq_hot_html_renderer works", {
+  expect_silent(dq_hot_selectize_renderer())
+})
